CREATE TABLE url (
  rec_id          serial primary key,
  status          int4 NOT NULL DEFAULT 0,
  docsize         int4 NOT NULL DEFAULT 0,
  next_index_time int4 NOT NULL,
  last_mod_time   int4 NOT NULL DEFAULT 0,
  referrer        int4 NOT NULL DEFAULT 0,
  hops            int4 NOT NULL DEFAULT 0,
  crc32           int4 NOT NULL DEFAULT -1,
  seed            int NOT NULL DEFAULT 0,
  bad_since_time  int4,
  server_id       int4,
  shows           int4 NOT NULL DEFAULT 0,
  url             text NOT NULL
);
CREATE UNIQUE INDEX url_url ON url (url);
CREATE INDEX url_crc             ON url (crc32);
CREATE INDEX url_seed            ON url (seed);
CREATE INDEX url_referrer        ON url (referrer);
CREATE INDEX url_next_index_time ON url (next_index_time);
CREATE INDEX url_status          ON url (status);
CREATE INDEX url_bad_since_time  ON url (bad_since_time);
CREATE INDEX url_hops            ON url (hops);
CREATE INDEX url_server_id       ON url (server_id);


CREATE TABLE urlinfo (
  url_id int4 NOT NULL,
  sname  text NOT NULL,
  sval   text NOT NULL
);
CREATE INDEX urlinfo_id ON urlinfo (url_id);


CREATE TABLE cachedcopy (
  url_id  int4  NOT NULL,
  ts      int4  NOT NULL,
  content bytea NOT NULL
);
CREATE INDEX cachedcopy_id ON cachedcopy (url_id);
CREATE INDEX cachedcopy_ts ON cachedcopy (ts);


CREATE TABLE dict (
  url_id int4 NOT NULL,
  word   text NOT NULL,
  coord  int4 NOT NULL
);
CREATE INDEX dict_word ON dict (word);
CREATE INDEX dict_url  ON dict ( url_id );
CREATE INDEX dict_word_url_id ON dict ( word, url_id );


CREATE TABLE bdict (
  word   varchar(255) NOT NULL,
  secno  int2         NOT NULL,
  coords bytea        NOT NULL
);
CREATE INDEX bdict_word ON bdict (word);


CREATE TABLE server (
  rec_id     int4    not null,
  enabled    int     not null  default 0,
  url        text    not null  default '',
  tag        text    not null  default '',
  command    char(1) not null  default 'S',
  ordre      int     not null  default 0,
  parent     int4    not null  default 0,
  weight     float   not null  default 1,
  pop_weight float   not null  default 0
);
ALTER TABLE ONLY server ADD CONSTRAINT server_pkey PRIMARY KEY (rec_id); 
CREATE INDEX srv_ordre ON server (ordre);
CREATE INDEX srv_parent ON server (parent);
CREATE INDEX srv_command ON server (command);
CREATE INDEX srv_tag ON SERVER (tag);


CREATE TABLE srvinfo (
   srv_id int4 NOT NULL,
   sname  text NOT NULL,
   sval   text NOT NULL
);
CREATE INDEX srvinfo_id ON srvinfo (srv_id);


CREATE FUNCTION clean_srvinfo() RETURNS trigger 
AS 'begin DELETE FROM srvinfo WHERE srv_id=old.rec_id; UPDATE url SET next_index_time=0 WHERE server_id=old.rec_id; return NULL; end;'
LANGUAGE plpgsql;

CREATE TRIGGER srvdel AFTER DELETE ON server FOR EACH ROW EXECUTE PROCEDURE clean_srvinfo();


CREATE TABLE links (
  url_id   int         not null default 0,
  seed     int         not null default 0,
  url      text        not null default '',
  src      varchar(10) not null default '',
  rel      varchar(32) not null default '',
  linktext text        not null default ''
);
CREATE TABLE links00 (CHECK( seed>=0   AND seed<16))  INHERITS (links);
CREATE TABLE links10 (CHECK( seed>=16  AND seed<32))  INHERITS (links);
CREATE TABLE links20 (CHECK( seed>=32  AND seed<48))  INHERITS (links);
CREATE TABLE links30 (CHECK( seed>=48  AND seed<64))  INHERITS (links);
CREATE TABLE links40 (CHECK( seed>=64  AND seed<80))  INHERITS (links);
CREATE TABLE links50 (CHECK( seed>=80  AND seed<96))  INHERITS (links);
CREATE TABLE links60 (CHECK( seed>=96  AND seed<112)) INHERITS (links);
CREATE TABLE links70 (CHECK( seed>=112 AND seed<128)) INHERITS (links);
CREATE TABLE links80 (CHECK( seed>=128 AND seed<144)) INHERITS (links);
CREATE TABLE links90 (CHECK( seed>=144 AND seed<160)) INHERITS (links);
CREATE TABLE linksA0 (CHECK( seed>=160 AND seed<176)) INHERITS (links);
CREATE TABLE linksB0 (CHECK( seed>=176 AND seed<192)) INHERITS (links);
CREATE TABLE linksC0 (CHECK( seed>=192 AND seed<208)) INHERITS (links);
CREATE TABLE linksD0 (CHECK( seed>=208 AND seed<224)) INHERITS (links);
CREATE TABLE linksE0 (CHECK( seed>=224 AND seed<240)) INHERITS (links);
CREATE TABLE linksF0 (CHECK( seed>=240 AND seed<256)) INHERITS (links);
CREATE INDEX key_links00_url_id ON links00 (url_id);
CREATE INDEX key_links10_url_id ON links10 (url_id);
CREATE INDEX key_links20_url_id ON links20 (url_id);
CREATE INDEX key_links30_url_id ON links30 (url_id);
CREATE INDEX key_links40_url_id ON links40 (url_id);
CREATE INDEX key_links50_url_id ON links50 (url_id);
CREATE INDEX key_links60_url_id ON links60 (url_id);
CREATE INDEX key_links70_url_id ON links70 (url_id);
CREATE INDEX key_links80_url_id ON links80 (url_id);
CREATE INDEX key_links90_url_id ON links90 (url_id);
CREATE INDEX key_linksA0_url_id ON linksA0 (url_id);
CREATE INDEX key_linksB0_url_id ON linksB0 (url_id);
CREATE INDEX key_linksC0_url_id ON linksC0 (url_id);
CREATE INDEX key_linksD0_url_id ON linksD0 (url_id);
CREATE INDEX key_linksE0_url_id ON linksE0 (url_id);
CREATE INDEX key_linksF0_url_id ON linksF0 (url_id);

CREATE OR REPLACE FUNCTION links_insert_trigger_func()
RETURNS TRIGGER AS $$
BEGIN
  IF    (NEW.seed >= 0   AND new.seed <16)  THEN INSERT INTO links00 VALUES(NEW.*)/**/;
  ELSIF (NEW.seed >= 16  AND new.seed <32)  THEN INSERT INTO links10 VALUES(NEW.*)/**/;
  ELSIF (NEW.seed >= 32  AND new.seed <48)  THEN INSERT INTO links20 VALUES(NEW.*)/**/;
  ELSIF (NEW.seed >= 48  AND new.seed <64)  THEN INSERT INTO links30 VALUES(NEW.*)/**/;
  ELSIF (NEW.seed >= 64  AND new.seed <80)  THEN INSERT INTO links40 VALUES(NEW.*)/**/;
  ELSIF (NEW.seed >= 80  AND new.seed <96)  THEN INSERT INTO links50 VALUES(NEW.*)/**/;
  ELSIF (NEW.seed >= 96  AND new.seed <112) THEN INSERT INTO links60 VALUES(NEW.*)/**/;
  ELSIF (NEW.seed >= 112 AND new.seed <128) THEN INSERT INTO links70 VALUES(NEW.*)/**/;
  ELSIF (NEW.seed >= 128 AND new.seed <144) THEN INSERT INTO links80 VALUES(NEW.*)/**/;
  ELSIF (NEW.seed >= 144 AND new.seed <160) THEN INSERT INTO links90 VALUES(NEW.*)/**/;
  ELSIF (NEW.seed >= 160 AND new.seed <176) THEN INSERT INTO linksA0 VALUES(NEW.*)/**/;
  ELSIF (NEW.seed >= 176 AND new.seed <192) THEN INSERT INTO linksB0 VALUES(NEW.*)/**/;
  ELSIF (NEW.seed >= 192 AND new.seed <208) THEN INSERT INTO linksC0 VALUES(NEW.*)/**/;
  ELSIF (NEW.seed >= 208 AND new.seed <224) THEN INSERT INTO linksD0 VALUES(NEW.*)/**/;
  ELSIF (NEW.seed >= 224 AND new.seed <240) THEN INSERT INTO linksE0 VALUES(NEW.*)/**/;
  ELSIF (NEW.seed >= 240 AND new.seed <256) THEN INSERT INTO linksF0 VALUES(NEW.*)/**/;
  ELSE RAISE EXCEPTION 'Seed out of range. Fix the links_insert_trigger_func() function!'/**/;
  END IF/**/;
  RETURN NULL/**/;
END/**/; $$
LANGUAGE plpgsql;

CREATE TRIGGER links_insert_trigger
BEFORE INSERT ON links
FOR EACH ROW EXECUTE PROCEDURE links_insert_trigger_func();


CREATE TABLE redirect (
  url_id int not null default 0,
  seed int not null default 0,
  url text not null default ''
);
CREATE INDEX key_redirect_url_id ON redirect (url_id);
CREATE INDEX key_redirect_seed   ON redirect (seed);


CREATE TABLE qtrack (
  rec_id serial4 primary key,
  ip     text NOT NULL,
  qwords text NOT NULL,
  qtime  int4 NOT NULL,
  wtime  int4 NOT NULL,
  nfound int4 NOT NULL
);
CREATE INDEX qtrack_ipt ON qtrack(ip,qtime);


CREATE TABLE qinfo (
  q_id  int4,
  sname text,
  sval  text
);
CREATE INDEX qinfo_id ON qinfo (q_id);
CREATE INDEX qinfo_nv ON qinfo (sname, sval);


CREATE TABLE wrdstat (
  word varchar(64) NOT NULL,
  snd  varchar(64) NOT NULL,
  cnt  int         NOT NULL
);
CREATE INDEX wrdstat_word ON wrdstat (word);
CREATE INDEX wrdstat_snd  ON wrdstat (snd);


CREATE TABLE qcache (
  id       INT   NOT NULL,
  tm       INT   NOT NULL,
  doclist  BYTEA NOT NULL,
  wordinfo TEXT  NOT NULL,
  PRIMARY KEY (id,tm)
);
CREATE INDEX key_qcache_tmstamp ON qcache(tm);
